@@ -58,6 +58,10 @@ static void
 cb_rstto_open_dir(GtkToolItem *item, RsttoNavigator *);
 static void
 cb_rstto_open_recent(GtkRecentChooser *chooser, RsttoNavigator *);
+static void
+cb_rstto_clear_recent(GtkWidget *widget, GtkRecentManager *manager);
+static gboolean
+rstto_clear_recent(GtkRecentManager *manager);
 
 static void
 cb_rstto_help_about(GtkToolItem *item, GtkWindow *);
@@ -95,6 +99,9 @@ static GtkWidget *status_bar;
 static gboolean playing = FALSE;
 static GtkWidget *menu_item_play;
 static GtkWidget *menu_item_pause;
+static GtkWidget *menu_item_htv;
+static GtkWidget *menu_item_vtv;
+static GtkWidget *menu_item_ntv;
 
 static GtkWidget *main_hbox;
 static GtkWidget *main_vbox1;
@@ -108,6 +115,7 @@ int main(int argc, char **argv)
 {
     ThunarVfsPath *path = NULL;
     GtkWidget *viewer = NULL;
+    gint n = 1;
 
 
     #ifdef ENABLE_NLS
@@ -131,6 +139,7 @@ int main(int argc, char **argv)
     gboolean show_toolbar = xfce_rc_read_bool_entry(xfce_rc, "ShowToolBar", TRUE);
     gint window_width = xfce_rc_read_int_entry(xfce_rc, "LastWindowWidth", 400);
     gint window_height = xfce_rc_read_int_entry(xfce_rc, "LastWindowHeight", 300);
+    gint slideshow_timeout = xfce_rc_read_int_entry(xfce_rc, "SlideShowTimeout", 5000);
 
     GtkWidget *window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     GtkAccelGroup *accel_group = gtk_accel_group_new();
@@ -142,6 +151,7 @@ int main(int argc, char **argv)
     g_signal_connect(G_OBJECT(window), "destroy", G_CALLBACK(gtk_main_quit), NULL);
 
     RsttoNavigator *navigator = rstto_navigator_new();
+    rstto_navigator_set_timeout(navigator, slideshow_timeout);
     thumbnail_viewer = rstto_thumbnail_viewer_new(navigator);
     viewer = rstto_picture_viewer_new(navigator);
 
@@ -149,10 +159,10 @@ int main(int argc, char **argv)
     g_signal_connect(G_OBJECT(navigator), "iter-changed", G_CALLBACK(cb_rstto_nav_file_changed), window);
 
 
-    if(argc == 2)
-        path = thunar_vfs_path_new(argv[1], NULL);
-    if (path)
+    for (n = 1; n < argc; ++n)
     {
+        path = thunar_vfs_path_new(argv[n], NULL);
+
         ThunarVfsInfo *info = thunar_vfs_info_new_for_path(path, NULL);
         if(info)
         {
@@ -163,11 +173,11 @@ int main(int argc, char **argv)
             }
             else
             {
-                GDir *dir = g_dir_open(argv[1], 0, NULL);
+                GDir *dir = g_dir_open(argv[n], 0, NULL);
                 const gchar *filename = g_dir_read_name(dir);
                 while (filename)
                 {
-                    gchar *path_name = g_strconcat(argv[1],  "/", filename, NULL);
+                    gchar *path_name = g_strconcat(argv[n],  "/", filename, NULL);
                     ThunarVfsPath *file_path = thunar_vfs_path_new(path_name, NULL);
                     if (file_path)
                     {
@@ -208,6 +218,7 @@ int main(int argc, char **argv)
     GtkWidget *menu_item_open_dir = gtk_menu_item_new_with_mnemonic(_("O_pen Folder"));
     GtkWidget *menu_item_recently = gtk_menu_item_new_with_mnemonic(_("_Recently used"));
     GtkWidget *menu_item_separator = gtk_separator_menu_item_new();
+    /* GtkWidget *menu_item_close = gtk_image_menu_item_new_from_stock(GTK_STOCK_CLOSE, accel_group); */
     GtkWidget *menu_item_quit = gtk_image_menu_item_new_from_stock(GTK_STOCK_QUIT, accel_group);
 
     GtkWidget *menu_file = gtk_menu_new();
@@ -216,6 +227,7 @@ int main(int argc, char **argv)
     gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_open_dir);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_recently);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_separator);
+    /* gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_close);*/
     gtk_menu_shell_append(GTK_MENU_SHELL(menu_file), menu_item_quit);
     
     GtkWidget *recent_chooser_menu = gtk_recent_chooser_menu_new_for_manager(GTK_RECENT_MANAGER(recent_manager));
@@ -223,6 +235,13 @@ int main(int argc, char **argv)
     gtk_recent_filter_add_application(filter, "ristretto");
     gtk_recent_chooser_add_filter(GTK_RECENT_CHOOSER(recent_chooser_menu), filter);
     
+    GtkWidget *menu_item_clear_recent = gtk_image_menu_item_new_with_mnemonic(_("_Clear"));
+    GtkWidget *img_clear_recent = gtk_image_new_from_stock(GTK_STOCK_CLEAR, GTK_ICON_SIZE_MENU);
+    gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item_clear_recent), img_clear_recent);
+    menu_item_separator = gtk_separator_menu_item_new();
+    gtk_menu_shell_append(GTK_MENU_SHELL(recent_chooser_menu), menu_item_separator);
+    gtk_menu_shell_append(GTK_MENU_SHELL(recent_chooser_menu), menu_item_clear_recent);
+    
     gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_recently), recent_chooser_menu);
 
     GtkWidget *menu_item_edit = gtk_menu_item_new_with_mnemonic(_("_Edit"));
@@ -254,9 +273,9 @@ int main(int argc, char **argv)
 
     GtkWidget *menu_tv = gtk_menu_new();
     gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item_tv), menu_tv);
-    GtkWidget *menu_item_htv = gtk_radio_menu_item_new_with_mnemonic(NULL, _("Show Horizontally"));
-    GtkWidget *menu_item_vtv = gtk_radio_menu_item_new_with_mnemonic_from_widget(GTK_RADIO_MENU_ITEM(menu_item_htv), _("Show Vertically"));
-    GtkWidget *menu_item_ntv = gtk_radio_menu_item_new_with_mnemonic_from_widget(GTK_RADIO_MENU_ITEM(menu_item_htv), _("Hide"));
+    menu_item_htv = gtk_radio_menu_item_new_with_mnemonic(NULL, _("Show Horizontally"));
+    menu_item_vtv = gtk_radio_menu_item_new_with_mnemonic_from_widget(GTK_RADIO_MENU_ITEM(menu_item_htv), _("Show Vertically"));
+    menu_item_ntv = gtk_radio_menu_item_new_with_mnemonic_from_widget(GTK_RADIO_MENU_ITEM(menu_item_htv), _("Hide"));
 
     gtk_menu_shell_append(GTK_MENU_SHELL(menu_tv), menu_item_htv);
     gtk_menu_shell_append(GTK_MENU_SHELL(menu_tv), menu_item_vtv);
@@ -368,6 +387,8 @@ int main(int argc, char **argv)
     else
         g_signal_connect(G_OBJECT(open), "clicked", G_CALLBACK(cb_rstto_open), navigator);
 
+    g_signal_connect(G_OBJECT(menu_item_clear_recent), "activate", G_CALLBACK(cb_rstto_clear_recent), recent_manager);
+
     g_signal_connect(G_OBJECT(menu_item_quit), "activate", G_CALLBACK(gtk_main_quit), NULL);
     g_signal_connect(G_OBJECT(menu_item_open), "activate", G_CALLBACK(cb_rstto_open), navigator);
     g_signal_connect(G_OBJECT(menu_item_open_dir), "activate", G_CALLBACK(cb_rstto_open_dir), navigator);
@@ -667,10 +688,25 @@ static gboolean
 cb_rstto_key_press_event(GtkWidget *widget, GdkEventKey *event, RsttoNavigator *navigator)
 {
     GtkWindow *window = GTK_WINDOW(widget);
-    if(!gtk_window_activate_key(window, event))
+    if(gtk_window_activate_key(window, event) == FALSE)
     {
         switch(event->keyval)
         {
+            case GDK_F5:
+                if(playing == TRUE)
+                {
+                    gtk_widget_show(menu_item_play);
+                    gtk_widget_hide(menu_item_pause);
+                    playing = FALSE;
+                }
+                else
+                {
+                    gtk_widget_hide(menu_item_play);
+                    gtk_widget_show(menu_item_pause);
+                    playing = TRUE;
+                }
+                rstto_navigator_set_running(navigator, playing);
+                break;
             case GDK_F11:
                 if(window_fullscreen)
                     gtk_window_unfullscreen(window);
@@ -691,9 +727,36 @@ cb_rstto_key_press_event(GtkWidget *widget, GdkEventKey *event, RsttoNavigator *
             case GDK_BackSpace:
                 rstto_navigator_jump_back(navigator);
                 break;
+            case GDK_t:
+                if (event->state & GDK_CONTROL_MASK)
+                {
+                    if(strcmp(xfce_rc_read_entry(xfce_rc, "ThumbnailViewerOrientation", "hide"), "hide"))
+                    {
+                        gtk_widget_hide(GTK_WIDGET(thumbnail_viewer));
+                        xfce_rc_write_entry(xfce_rc, "ThumbnailViewerOrientation", "hide");
+                        gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu_item_ntv), TRUE);
+                    }
+                    else
+                    {
+                        gtk_widget_show(GTK_WIDGET(thumbnail_viewer));
+                        switch (rstto_thumbnail_viewer_get_orientation(RSTTO_THUMBNAIL_VIEWER(thumbnail_viewer)))
+                        {
+                            case GTK_ORIENTATION_HORIZONTAL:
+                                xfce_rc_write_entry(xfce_rc, "ThumbnailViewerOrientation", "horizontal");
+                                gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu_item_htv), TRUE);
+                                break;
+                            case GTK_ORIENTATION_VERTICAL:
+                                xfce_rc_write_entry(xfce_rc, "ThumbnailViewerOrientation", "vertical");
+                                gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu_item_vtv), TRUE);
+                                break;
+                        }
+
+                    }
+                }
+                break;
         }
     }
-    return FALSE;
+    return TRUE;
 }
 
 static void
@@ -917,3 +980,25 @@ cb_rstto_main_window_configure_event (GtkWidget *widget, GdkEventConfigure *even
     /* let Gtk+ handle the configure event */
     return FALSE;
 }
+
+static void
+cb_rstto_clear_recent(GtkWidget *widget, GtkRecentManager *manager)
+{
+    g_timeout_add(150, (GSourceFunc)rstto_clear_recent, manager);
+}
+
+static gboolean
+rstto_clear_recent(GtkRecentManager *manager)
+{
+    GList *items = gtk_recent_manager_get_items(manager);
+    GList *iter = items;
+    while(iter)
+    {
+        if(gtk_recent_info_has_application(iter->data, "ristretto"))
+        {
+            gtk_recent_manager_remove_item(manager, gtk_recent_info_get_uri(iter->data), NULL);
+        }
+        iter = g_list_next(iter);
+    }
+    return FALSE;
+}
