@@ -375,7 +375,9 @@ cb_rstto_picture_viewer_value_changed(GtkAdjustment *adjustment, RsttoPictureVie
         GdkPixbuf *tmp_pixbuf = NULL;
         if (viewer->hadjustment && viewer->vadjustment)
         {
-            tmp_pixbuf = gdk_pixbuf_new_subpixbuf(viewer->priv->src_pixbuf,
+            if (scale < 1.0)
+            {
+                tmp_pixbuf = gdk_pixbuf_new_subpixbuf(viewer->priv->src_pixbuf,
                             viewer->hadjustment->value / scale >= 0?
                                 viewer->hadjustment->value / scale : 0,
                             viewer->vadjustment->value / scale >= 0?
@@ -384,6 +386,12 @@ cb_rstto_picture_viewer_value_changed(GtkAdjustment *adjustment, RsttoPictureVie
                                 GTK_WIDGET(viewer)->allocation.width/scale:width,
                             ((GTK_WIDGET(viewer)->allocation.height/scale)) < height?
                                 GTK_WIDGET(viewer)->allocation.height/scale:height);
+            }
+            else
+            {
+                tmp_pixbuf = viewer->priv->src_pixbuf;
+                g_object_ref(tmp_pixbuf);
+            }
         }
 
         if(viewer->priv->dst_pixbuf)
@@ -562,7 +570,7 @@ rstto_picture_viewer_refresh(RsttoPictureViewer *viewer)
             GdkPixbuf *tmp_pixbuf = NULL;
             if (viewer->vadjustment && viewer->hadjustment)
             {
-                if (scale != 1.0)
+                if (scale < 1.0)
                 {
                     tmp_pixbuf = gdk_pixbuf_new_subpixbuf(viewer->priv->src_pixbuf,
                                                       viewer->hadjustment->value / scale >= 0?
@@ -619,7 +627,10 @@ rstto_picture_viewer_refresh(RsttoPictureViewer *viewer)
 static gboolean
 cb_rstto_picture_viewer_update_image(RsttoPictureViewer *viewer)
 {
-    if (g_timer_elapsed(viewer->priv->timer, NULL) > 0.2)
+    gulong millisec = 0;
+
+    g_timer_elapsed(viewer->priv->timer, &millisec);
+    if (millisec > 150)
     {
         g_timer_stop(viewer->priv->timer);
         viewer->priv->timeout_id = 0;
@@ -632,9 +643,17 @@ cb_rstto_picture_viewer_update_image(RsttoPictureViewer *viewer)
 static void
 cb_rstto_picture_viewer_nav_file_changed(RsttoNavigator *nav, gint nr, RsttoNavigatorEntry *entry, RsttoPictureViewer *viewer)
 {
+    GtkWidget *widget = GTK_WIDGET(viewer);
+    if (GTK_WIDGET_REALIZED(widget))
+    {
+        GdkCursor *cursor = gdk_cursor_new(GDK_WATCH);
+        gdk_window_set_cursor(widget->window, cursor);
+        gdk_cursor_unref(cursor);
+    }
     g_timer_start(viewer->priv->timer);
     if (viewer->priv->timeout_id == 0)
-        viewer->priv->timeout_id = g_timeout_add(200, (GSourceFunc)cb_rstto_picture_viewer_update_image, viewer);
+        viewer->priv->timeout_id = g_timeout_add(150, (GSourceFunc)cb_rstto_picture_viewer_update_image, viewer);
+
 }
 
 static void
@@ -681,11 +700,15 @@ cb_rstto_picture_viewer_scroll_event (RsttoPictureViewer *viewer, GdkEventScroll
     {
         case GDK_SCROLL_UP:
         case GDK_SCROLL_LEFT:
+            if (scale <= 0.05)
+                return;
             rstto_navigator_entry_set_scale(entry, scale / 1.2);
             rstto_navigator_entry_set_fit_to_screen (entry, FALSE);
             break;
         case GDK_SCROLL_DOWN:
         case GDK_SCROLL_RIGHT:
+            if (scale >= 16)
+                return;
             viewer->vadjustment->value = ((viewer->vadjustment->value + event->y) - viewer->vadjustment->page_size/2) * 1.2;
             viewer->hadjustment->value = ((viewer->hadjustment->value + event->x) - viewer->hadjustment->page_size/2) * 1.2;
 
